triflow — triflow 0.4.3 documentation

# triflow

- triflow package
  - Subpackages
    - triflow.core package
      - Submodules
      - triflow.core.fields module
      - triflow.core.model module
      - triflow.core.routines module
      - triflow.core.simulation module
      - Module contents
    - triflow.plugins package
      - Submodules
      - triflow.plugins.displays module
      - triflow.plugins.schemes module
      - triflow.plugins.signals module
      - Module contents
  - Module contents